import setuptools

setuptools.setup(
	
	name = 'lacdkeras',
	packages = setuptools.find_packages(),
	version = '1.0.0.2',
	description = 'ncku AI camp',
	author = 'HuangTeEn',
	author_email = 'qaz910048@gmail.com',
	keywords = ['Keras','Teach','lacd'],
    license='MIT'
)